=======
Physics
=======

Sub-commands to support the physics components

Source terms
~~~~~~~~~~~~

.. autosummary::
   :nosignatures:
   :toctree: _generated/

   rompy_swan.subcomponents.physics.JANSSEN
   rompy_swan.subcomponents.physics.KOMEN
   rompy_swan.subcomponents.physics.WESTHUYSEN
   rompy_swan.subcomponents.physics.ST6


ST6 presets
~~~~~~~~~~~

Combinations of calibrated coefficients for ST6 are defined in the `SWAN Manual`_.
The following presets are available:

.. autosummary::
   :nosignatures:
   :toctree: _generated/

   rompy_swan.subcomponents.physics.ST6C1
   rompy_swan.subcomponents.physics.ST6C2
   rompy_swan.subcomponents.physics.ST6C3
   rompy_swan.subcomponents.physics.ST6C4
   rompy_swan.subcomponents.physics.ST6C5


Biphase
~~~~~~~

.. autosummary::
   :nosignatures:
   :toctree: _generated/

   rompy_swan.subcomponents.physics.ELDEBERKY
   rompy_swan.subcomponents.physics.DEWIT


Transmission and reflection
~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autosummary::
   :nosignatures:
   :toctree: _generated/

   rompy_swan.subcomponents.physics.TRANSM
   rompy_swan.subcomponents.physics.TRANS1D
   rompy_swan.subcomponents.physics.TRANS2D
   rompy_swan.subcomponents.physics.GODA
   rompy_swan.subcomponents.physics.DANGREMOND
   rompy_swan.subcomponents.physics.REFL
   rompy_swan.subcomponents.physics.RSPEC
   rompy_swan.subcomponents.physics.RDIFF
   rompy_swan.subcomponents.physics.FREEBOARD
   rompy_swan.subcomponents.physics.LINE


.. _`SWAN Manual`: https://swanmodel.sourceforge.io/online_doc/swanuse/node28.html
